@@ -654,7 +654,7 @@ bool FileAccessJobHandler::stat( int detail, bool bWantToWrite )
    m_pFileAccess->m_statusText = TQString();
    TDEIO::StatJob* pStatJob = TDEIO::stat( m_pFileAccess->m_url, ! bWantToWrite, detail, false );
 
-   connect( pStatJob, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotStatResult(TDEIO::Job*)));
+   connect( pStatJob, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotStatResult(TDEIO::Job*)));
 
    g_pProgressDialog->enterEventLoop( pStatJob, i18n("Getting file status: %1").arg(m_pFileAccess->prettyAbsPath()) );
 
@@ -695,9 +695,9 @@ bool FileAccessJobHandler::get(void* pDestBuffer, long maxLength )
       m_bSuccess = false;
       m_pFileAccess->m_statusText = TQString();
 
-      connect( pJob, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotSimpleJobResult(TDEIO::Job*)));
-      connect( pJob, TQT_SIGNAL(data(TDEIO::Job*,const TQByteArray &)), this, TQT_SLOT(slotGetData(TDEIO::Job*, const TQByteArray&)));
-      connect( pJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQT_SLOT(slotPercent(TDEIO::Job*, unsigned long)));
+      connect( pJob, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotSimpleJobResult(TDEIO::Job*)));
+      connect( pJob, TQ_SIGNAL(data(TDEIO::Job*,const TQByteArray &)), this, TQ_SLOT(slotGetData(TDEIO::Job*, const TQByteArray&)));
+      connect( pJob, TQ_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQ_SLOT(slotPercent(TDEIO::Job*, unsigned long)));
 
       g_pProgressDialog->enterEventLoop( pJob, i18n("Reading file: %1").arg(m_pFileAccess->prettyAbsPath()) );
       return m_bSuccess;
@@ -731,9 +731,9 @@ bool FileAccessJobHandler::put(const void* pSrcBuffer, long maxLength, bool bOve
       m_bSuccess = false;
       m_pFileAccess->m_statusText = TQString();
 
-      connect( pJob, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotPutJobResult(TDEIO::Job*)));
-      connect( pJob, TQT_SIGNAL(dataReq(TDEIO::Job*, TQByteArray&)), this, TQT_SLOT(slotPutData(TDEIO::Job*, TQByteArray&)));
-      connect( pJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQT_SLOT(slotPercent(TDEIO::Job*, unsigned long)));
+      connect( pJob, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotPutJobResult(TDEIO::Job*)));
+      connect( pJob, TQ_SIGNAL(dataReq(TDEIO::Job*, TQByteArray&)), this, TQ_SLOT(slotPutData(TDEIO::Job*, TQByteArray&)));
+      connect( pJob, TQ_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQ_SLOT(slotPercent(TDEIO::Job*, unsigned long)));
 
       g_pProgressDialog->enterEventLoop( pJob, i18n("Writing file: %1").arg(m_pFileAccess->prettyAbsPath()) );
       return m_bSuccess;
@@ -796,7 +796,7 @@ bool FileAccessJobHandler::mkDir( const TQString& dirName )
    {
       m_bSuccess = false;
       TDEIO::SimpleJob* pJob = TDEIO::mkdir( dirURL );
-      connect( pJob, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotSimpleJobResult(TDEIO::Job*)));
+      connect( pJob, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotSimpleJobResult(TDEIO::Job*)));
 
       g_pProgressDialog->enterEventLoop( pJob, i18n("Making directory: %1").arg(dirName) );
       return m_bSuccess;
@@ -816,7 +816,7 @@ bool FileAccessJobHandler::rmDir( const TQString& dirName )
    {
       m_bSuccess = false;
       TDEIO::SimpleJob* pJob = TDEIO::rmdir( dirURL );
-      connect( pJob, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotSimpleJobResult(TDEIO::Job*)));
+      connect( pJob, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotSimpleJobResult(TDEIO::Job*)));
 
       g_pProgressDialog->enterEventLoop(pJob, i18n("Removing directory: %1").arg(dirName));
       return m_bSuccess;
@@ -831,7 +831,7 @@ bool FileAccessJobHandler::removeFile( const TQString& fileName )
    {
       m_bSuccess = false;
       TDEIO::SimpleJob* pJob = TDEIO::file_delete( KURL::fromPathOrURL(fileName), false );
-      connect( pJob, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotSimpleJobResult(TDEIO::Job*)));
+      connect( pJob, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotSimpleJobResult(TDEIO::Job*)));
 
       g_pProgressDialog->enterEventLoop( pJob, i18n("Removing file: %1").arg(fileName) );
       return m_bSuccess;
@@ -846,7 +846,7 @@ bool FileAccessJobHandler::symLink( const TQString& linkTarget, const TQString&
    {
       m_bSuccess = false;
       TDEIO::CopyJob* pJob = TDEIO::link( KURL::fromPathOrURL(linkTarget), KURL::fromPathOrURL(linkLocation), false );
-      connect( pJob, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotSimpleJobResult(TDEIO::Job*)));
+      connect( pJob, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotSimpleJobResult(TDEIO::Job*)));
 
       g_pProgressDialog->enterEventLoop( pJob,
          i18n("Creating symbolic link: %1 -> %2").arg(linkLocation).arg(linkTarget) );
@@ -875,8 +875,8 @@ bool FileAccessJobHandler::rename( const TQString& dest )
       int permissions=-1;
       m_bSuccess = false;
       TDEIO::FileCopyJob* pJob = TDEIO::file_move( m_pFileAccess->m_url, kurl, permissions, bOverwrite, bResume, bShowProgress );
-      connect( pJob, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotSimpleJobResult(TDEIO::Job*)));
-      connect( pJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQT_SLOT(slotPercent(TDEIO::Job*, unsigned long)));
+      connect( pJob, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotSimpleJobResult(TDEIO::Job*)));
+      connect( pJob, TQ_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQ_SLOT(slotPercent(TDEIO::Job*, unsigned long)));
 
       g_pProgressDialog->enterEventLoop( pJob,
          i18n("Renaming file: %1 -> %2").arg(m_pFileAccess->prettyAbsPath()).arg(dest) );
@@ -912,8 +912,8 @@ bool FileAccessJobHandler::copyFile( const TQString& dest )
       int permissions = (m_pFileAccess->isExecutable()?0111:0)+(m_pFileAccess->isWritable()?0222:0)+(m_pFileAccess->isReadable()?0444:0);
       m_bSuccess = false;
       TDEIO::FileCopyJob* pJob = TDEIO::file_copy ( m_pFileAccess->m_url, destUrl, permissions, bOverwrite, bResume, bShowProgress );
-      connect( pJob, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(slotSimpleJobResult(TDEIO::Job*)));
-      connect( pJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQT_SLOT(slotPercent(TDEIO::Job*, unsigned long)));
+      connect( pJob, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(slotSimpleJobResult(TDEIO::Job*)));
+      connect( pJob, TQ_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQ_SLOT(slotPercent(TDEIO::Job*, unsigned long)));
       g_pProgressDialog->enterEventLoop( pJob,
          i18n("Copying file: %1 -> %2").arg(m_pFileAccess->prettyAbsPath()).arg(dest) );
 
@@ -1363,16 +1363,16 @@ bool FileAccessJobHandler::listDir( t_DirectoryList* pDirList, bool bRecursive,
       m_bSuccess = false;
       if ( pListJob!=0 )
       {
-         connect( pListJob, TQT_SIGNAL( entries( TDEIO::Job *, const TDEIO::UDSEntryList& ) ),
-                  this,     TQT_SLOT( slotListDirProcessNewEntries( TDEIO::Job *, const TDEIO::UDSEntryList& )) );
-         connect( pListJob, TQT_SIGNAL( result( TDEIO::Job* )),
-                  this,     TQT_SLOT( slotSimpleJobResult(TDEIO::Job*) ) );
+         connect( pListJob, TQ_SIGNAL( entries( TDEIO::Job *, const TDEIO::UDSEntryList& ) ),
+                  this,     TQ_SLOT( slotListDirProcessNewEntries( TDEIO::Job *, const TDEIO::UDSEntryList& )) );
+         connect( pListJob, TQ_SIGNAL( result( TDEIO::Job* )),
+                  this,     TQ_SLOT( slotSimpleJobResult(TDEIO::Job*) ) );
 
-         connect( pListJob, TQT_SIGNAL( infoMessage(TDEIO::Job*, const TQString&)),
-                  this,     TQT_SLOT( slotListDirInfoMessage(TDEIO::Job*, const TQString&) ));
+         connect( pListJob, TQ_SIGNAL( infoMessage(TDEIO::Job*, const TQString&)),
+                  this,     TQ_SLOT( slotListDirInfoMessage(TDEIO::Job*, const TQString&) ));
 
          // This line makes the transfer via fish unreliable.:-(
-         //connect( pListJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQT_SLOT(slotPercent(TDEIO::Job*, unsigned long)));
+         //connect( pListJob, TQ_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQ_SLOT(slotPercent(TDEIO::Job*, unsigned long)));
 
          g_pProgressDialog->enterEventLoop( pListJob,
             i18n("Listing directory: %1").arg(m_pFileAccess->prettyAbsPath()) );
@@ -1506,7 +1506,7 @@ ProgressDialog::ProgressDialog( TQWidget* pParent )
    hlayout->addStretch(1);
    m_pAbortButton = new TQPushButton( i18n("&Cancel"), this);
    hlayout->addWidget( m_pAbortButton );
-   connect( m_pAbortButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotAbort()) );
+   connect( m_pAbortButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotAbort()) );
 
    m_progressDelayTimer = 0;
    resize( 400, 100 );
@@ -1713,7 +1713,7 @@ void ProgressDialog::hide()
    killTimer( m_progressDelayTimer );
    m_progressDelayTimer = 0;
    // Calling TQDialog::hide() directly doesn't always work. (?)
-   TQTimer::singleShot( 100, this, TQT_SLOT(delayedHide()) );
+   TQTimer::singleShot( 100, this, TQ_SLOT(delayedHide()) );
 }
 
 void ProgressDialog::delayedHide()
