@@ -36,14 +36,14 @@
 
 // include files for KDE
 #include <kiconloader.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
-#include <kmenubar.h>
+#include <tdemessagebox.h>
+#include <tdefiledialog.h>
+#include <tdemenubar.h>
 #include <kstatusbar.h>
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
 #include <kstdaction.h>
-#include <kcmdlineargs.h>
+#include <tdecmdlineargs.h>
 #include <kprinter.h>
 //#include <kkeydialog.h>
 
@@ -57,7 +57,7 @@
 
 #define ID_STATUS_MSG 1
 
-KActionCollection* KDiff3App::actionCollection()
+TDEActionCollection* KDiff3App::actionCollection()
 {
    if ( m_pKDiff3Shell==0 )
       return m_pKDiff3Part->actionCollection();
@@ -73,7 +73,7 @@ KStatusBar* KDiff3App::statusBar()
       return m_pKDiff3Shell->statusBar();
 }
 
-KToolBar* KDiff3App::toolBar(const char* toolBarId )
+TDEToolBar* KDiff3App::toolBar(const char* toolBarId )
 {
    if ( m_pKDiff3Shell==0 )
       return 0;
@@ -92,7 +92,7 @@ bool KDiff3App::isFileSaved()
 }
 
 KDiff3App::KDiff3App(TQWidget* pParent, const char* name, KDiff3Part* pKDiff3Part )
-   :TQSplitter(pParent, name)  //previously KMainWindow
+   :TQSplitter(pParent, name)  //previously TDEMainWindow
 {
    m_pKDiff3Part = pKDiff3Part;
    m_pKDiff3Shell = dynamic_cast<KParts::MainWindow*>(pParent);
@@ -128,12 +128,12 @@ KDiff3App::KDiff3App(TQWidget* pParent, const char* name, KDiff3Part* pKDiff3Par
 
    // All default values must be set before calling readOptions().
    m_pOptionDialog = new OptionDialog( m_pKDiff3Shell!=0, this );
-   connect( m_pOptionDialog, TQT_SIGNAL(applyClicked()), TQT_TQOBJECT(this), TQT_SLOT(slotRefresh()) );
+   connect( m_pOptionDialog, TQ_SIGNAL(applyClicked()), this, TQ_SLOT(slotRefresh()) );
 
    m_pOptionDialog->readOptions( isPart() ? m_pKDiff3Part->instance()->config() : kapp->config() );
 
    // Option handling: Only when pParent==0 (no parent)
-   KCmdLineArgs *args = isPart() ? 0 : KCmdLineArgs::parsedArgs();
+   TDECmdLineArgs *args = isPart() ? 0 : TDECmdLineArgs::parsedArgs();
 
    if (args)
    {
@@ -243,7 +243,7 @@ KDiff3App::KDiff3App(TQWidget* pParent, const char* name, KDiff3Part* pKDiff3Par
    initStatusBar();
 
    m_pFindDialog = new FindDialog( this );
-   connect( m_pFindDialog, TQT_SIGNAL(findNext()), TQT_TQOBJECT(this), TQT_SLOT(slotEditFindNext()));
+   connect( m_pFindDialog, TQ_SIGNAL(findNext()), this, TQ_SLOT(slotEditFindNext()));
 
    autoAdvance->setChecked( m_pOptionDialog->m_bAutoAdvance );
    showWhiteSpaceCharacters->setChecked( m_pOptionDialog->m_bShowWhiteSpaceCharacters );
@@ -258,7 +258,7 @@ KDiff3App::KDiff3App(TQWidget* pParent, const char* name, KDiff3Part* pKDiff3Par
       slotViewToolBar();
       slotViewStatusBar();
       if( toolBar("mainToolBar")!=0 )
-         toolBar("mainToolBar")->setBarPos( (KToolBar::BarPosition) m_pOptionDialog->m_toolBarPos );
+         toolBar("mainToolBar")->setBarPos( (TDEToolBar::BarPosition) m_pOptionDialog->m_toolBarPos );
 /*      TQSize size = m_pOptionDialog->m_geometry;
       TQPoint pos = m_pOptionDialog->m_position;
       if(!size.isEmpty())
@@ -272,23 +272,23 @@ KDiff3App::KDiff3App(TQWidget* pParent, const char* name, KDiff3Part* pKDiff3Par
    slotRefresh();
 
    m_pMainSplitter = this; //new TQSplitter(this);
-   m_pMainSplitter->setOrientation(Qt::Vertical );
+   m_pMainSplitter->setOrientation(TQt::Vertical );
 //   setCentralWidget( m_pMainSplitter );
    m_pDirectoryMergeSplitter = new TQSplitter( m_pMainSplitter );
-   m_pDirectoryMergeSplitter->setOrientation(Qt::Horizontal );
+   m_pDirectoryMergeSplitter->setOrientation(TQt::Horizontal );
    m_pDirectoryMergeWindow = new DirectoryMergeWindow( m_pDirectoryMergeSplitter, m_pOptionDialog,
-      KApplication::kApplication()->iconLoader() );
+      TDEApplication::kApplication()->iconLoader() );
    m_pDirectoryMergeInfo = new DirectoryMergeInfo( m_pDirectoryMergeSplitter );
    m_pDirectoryMergeWindow->setDirectoryMergeInfo( m_pDirectoryMergeInfo );
-   connect( m_pDirectoryMergeWindow, TQT_SIGNAL(startDiffMerge(TQString,TQString,TQString,TQString,TQString,TQString,TQString,TotalDiffStatus*)),
-            TQT_TQOBJECT(this), TQT_SLOT( slotFileOpen2(TQString,TQString,TQString,TQString,TQString,TQString,TQString,TotalDiffStatus*)));
-   connect( m_pDirectoryMergeWindow, TQT_SIGNAL(selectionChanged()), TQT_TQOBJECT(this), TQT_SLOT(slotUpdateAvailabilities()));
-   connect( m_pDirectoryMergeWindow, TQT_SIGNAL(currentChanged(TQListViewItem*)), TQT_TQOBJECT(this), TQT_SLOT(slotUpdateAvailabilities()));
-   connect( m_pDirectoryMergeWindow, TQT_SIGNAL(checkIfCanContinue(bool*)), TQT_TQOBJECT(this), TQT_SLOT(slotCheckIfCanContinue(bool*)));
-   connect( m_pDirectoryMergeWindow, TQT_SIGNAL(updateAvailabilities()), TQT_TQOBJECT(this), TQT_SLOT(slotUpdateAvailabilities()));
-   connect( m_pDirectoryMergeWindow, TQT_SIGNAL(statusBarMessage(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(slotStatusMsg(const TQString&)));
+   connect( m_pDirectoryMergeWindow, TQ_SIGNAL(startDiffMerge(TQString,TQString,TQString,TQString,TQString,TQString,TQString,TotalDiffStatus*)),
+            this, TQ_SLOT( slotFileOpen2(TQString,TQString,TQString,TQString,TQString,TQString,TQString,TotalDiffStatus*)));
+   connect( m_pDirectoryMergeWindow, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(slotUpdateAvailabilities()));
+   connect( m_pDirectoryMergeWindow, TQ_SIGNAL(currentChanged(TQListViewItem*)), this, TQ_SLOT(slotUpdateAvailabilities()));
+   connect( m_pDirectoryMergeWindow, TQ_SIGNAL(checkIfCanContinue(bool*)), this, TQ_SLOT(slotCheckIfCanContinue(bool*)));
+   connect( m_pDirectoryMergeWindow, TQ_SIGNAL(updateAvailabilities()), this, TQ_SLOT(slotUpdateAvailabilities()));
+   connect( m_pDirectoryMergeWindow, TQ_SIGNAL(statusBarMessage(const TQString&)), this, TQ_SLOT(slotStatusMsg(const TQString&)));
 
-   m_pDirectoryMergeWindow->initDirectoryMergeActions( TQT_TQOBJECT(this), actionCollection() );
+   m_pDirectoryMergeWindow->initDirectoryMergeActions( this, actionCollection() );
 
    if ( args!=0 )  args->clear(); // Free up some memory.
 
@@ -426,41 +426,41 @@ KDiff3App::~KDiff3App()
 
 }
 
-void KDiff3App::initActions( KActionCollection* ac )
+void KDiff3App::initActions( TDEActionCollection* ac )
 {
    if (ac==0)   KMessageBox::error(0, "actionCollection==0");
 
-   fileOpen = KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(slotFileOpen()), ac);
+   fileOpen = KStdAction::open(this, TQ_SLOT(slotFileOpen()), ac);
    fileOpen->setStatusText(i18n("Opens documents for comparison..."));
 
-   fileReload  = new KAction(i18n("Reload"), /*TQIconSet(TQPixmap(reloadIcon)),*/ Key_F5, TQT_TQOBJECT(this), TQT_SLOT(slotReload()), ac, "file_reload");
+   fileReload  = new TDEAction(i18n("Reload"), /*TQIconSet(TQPixmap(reloadIcon)),*/ Key_F5, this, TQ_SLOT(slotReload()), ac, "file_reload");
    
-   fileSave = KStdAction::save(TQT_TQOBJECT(this), TQT_SLOT(slotFileSave()), ac);
+   fileSave = KStdAction::save(this, TQ_SLOT(slotFileSave()), ac);
    fileSave->setStatusText(i18n("Saves the merge result. All conflicts must be solved!"));
-   fileSaveAs = KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(slotFileSaveAs()), ac);
+   fileSaveAs = KStdAction::saveAs(this, TQ_SLOT(slotFileSaveAs()), ac);
    fileSaveAs->setStatusText(i18n("Saves the current document as..."));
-   filePrint = KStdAction::print(TQT_TQOBJECT(this), TQT_SLOT(slotFilePrint()), ac);
+   filePrint = KStdAction::print(this, TQ_SLOT(slotFilePrint()), ac);
    filePrint->setStatusText(i18n("Print the differences"));
-   fileQuit = KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(slotFileQuit()), ac);
+   fileQuit = KStdAction::quit(this, TQ_SLOT(slotFileQuit()), ac);
    fileQuit->setStatusText(i18n("Quits the application"));
-   editCut = KStdAction::cut(TQT_TQOBJECT(this), TQT_SLOT(slotEditCut()), ac);
+   editCut = KStdAction::cut(this, TQ_SLOT(slotEditCut()), ac);
    editCut->setStatusText(i18n("Cuts the selected section and puts it to the clipboard"));
-   editCopy = KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(slotEditCopy()), ac);
+   editCopy = KStdAction::copy(this, TQ_SLOT(slotEditCopy()), ac);
    editCopy->setStatusText(i18n("Copies the selected section to the clipboard"));
-   editPaste = KStdAction::paste(TQT_TQOBJECT(this), TQT_SLOT(slotEditPaste()), ac);
+   editPaste = KStdAction::paste(this, TQ_SLOT(slotEditPaste()), ac);
    editPaste->setStatusText(i18n("Pastes the clipboard contents to actual position"));
-   editSelectAll = KStdAction::selectAll(TQT_TQOBJECT(this), TQT_SLOT(slotEditSelectAll()), ac);
+   editSelectAll = KStdAction::selectAll(this, TQ_SLOT(slotEditSelectAll()), ac);
    editSelectAll->setStatusText(i18n("Select everything in current window"));
-   editFind = KStdAction::find(TQT_TQOBJECT(this), TQT_SLOT(slotEditFind()), ac);
+   editFind = KStdAction::find(this, TQ_SLOT(slotEditFind()), ac);
    editFind->setStatusText(i18n("Search for a string"));
-   editFindNext = KStdAction::findNext(TQT_TQOBJECT(this), TQT_SLOT(slotEditFindNext()), ac);
+   editFindNext = KStdAction::findNext(this, TQ_SLOT(slotEditFindNext()), ac);
    editFindNext->setStatusText(i18n("Search again for the string"));
-   viewToolBar = KStdAction::showToolbar(TQT_TQOBJECT(this), TQT_SLOT(slotViewToolBar()), ac);
+   viewToolBar = KStdAction::showToolbar(this, TQ_SLOT(slotViewToolBar()), ac);
    viewToolBar->setStatusText(i18n("Enables/disables the toolbar"));
-   viewStatusBar = KStdAction::showStatusbar(TQT_TQOBJECT(this), TQT_SLOT(slotViewStatusBar()), ac);
+   viewStatusBar = KStdAction::showStatusbar(this, TQ_SLOT(slotViewStatusBar()), ac);
    viewStatusBar->setStatusText(i18n("Enables/disables the statusbar"));
-   KStdAction::keyBindings(TQT_TQOBJECT(this), TQT_SLOT(slotConfigureKeys()), ac);
-   KAction* pAction = KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(slotConfigure()), ac );
+   KStdAction::keyBindings(this, TQ_SLOT(slotConfigureKeys()), ac);
+   TDEAction* pAction = KStdAction::preferences(this, TQ_SLOT(slotConfigure()), ac );
    if ( isPart() )
       pAction->setText(i18n("Configure KDiff3..."));
 
@@ -483,70 +483,70 @@ void KDiff3App::initActions( KActionCollection* ac )
 #include "xpm/showlinenumbers.xpm"
 //#include "reload.xpm"
 
-   goCurrent = new KAction(i18n("Go to Current Delta"), TQIconSet(TQPixmap(currentpos)), CTRL+Key_Space, TQT_TQOBJECT(this), TQT_SLOT(slotGoCurrent()), ac, "go_current");
-   goTop = new KAction(i18n("Go to First Delta"), TQIconSet(TQPixmap(upend)), 0, TQT_TQOBJECT(this), TQT_SLOT(slotGoTop()), ac, "go_top");
-   goBottom = new KAction(i18n("Go to Last Delta"), TQIconSet(TQPixmap(downend)), 0, TQT_TQOBJECT(this), TQT_SLOT(slotGoBottom()), ac, "go_bottom");
+   goCurrent = new TDEAction(i18n("Go to Current Delta"), TQIconSet(TQPixmap(currentpos)), CTRL+Key_Space, this, TQ_SLOT(slotGoCurrent()), ac, "go_current");
+   goTop = new TDEAction(i18n("Go to First Delta"), TQIconSet(TQPixmap(upend)), 0, this, TQ_SLOT(slotGoTop()), ac, "go_top");
+   goBottom = new TDEAction(i18n("Go to Last Delta"), TQIconSet(TQPixmap(downend)), 0, this, TQ_SLOT(slotGoBottom()), ac, "go_bottom");
    TQString omitsWhitespace = ".\n" + i18n("(Skips white space differences when \"Show White Space\" is disabled.)");
    TQString includeWhitespace = ".\n" + i18n("(Does not skip white space differences even when \"Show White Space\" is disabled.)");
-   goPrevDelta = new KAction(i18n("Go to Previous Delta"), TQIconSet(TQPixmap(up1arrow)), CTRL+Key_Up, TQT_TQOBJECT(this), TQT_SLOT(slotGoPrevDelta()), ac, "go_prev_delta");
+   goPrevDelta = new TDEAction(i18n("Go to Previous Delta"), TQIconSet(TQPixmap(up1arrow)), CTRL+Key_Up, this, TQ_SLOT(slotGoPrevDelta()), ac, "go_prev_delta");
    goPrevDelta->setToolTip( goPrevDelta->text() + omitsWhitespace );
-   goNextDelta = new KAction(i18n("Go to Next Delta"), TQIconSet(TQPixmap(down1arrow)), CTRL+Key_Down, TQT_TQOBJECT(this), TQT_SLOT(slotGoNextDelta()), ac, "go_next_delta");
+   goNextDelta = new TDEAction(i18n("Go to Next Delta"), TQIconSet(TQPixmap(down1arrow)), CTRL+Key_Down, this, TQ_SLOT(slotGoNextDelta()), ac, "go_next_delta");
    goNextDelta->setToolTip( goNextDelta->text() + omitsWhitespace );
-   goPrevConflict = new KAction(i18n("Go to Previous Conflict"), TQIconSet(TQPixmap(up2arrow)), CTRL+Key_PageUp, TQT_TQOBJECT(this), TQT_SLOT(slotGoPrevConflict()), ac, "go_prev_conflict");
+   goPrevConflict = new TDEAction(i18n("Go to Previous Conflict"), TQIconSet(TQPixmap(up2arrow)), CTRL+Key_PageUp, this, TQ_SLOT(slotGoPrevConflict()), ac, "go_prev_conflict");
    goPrevConflict->setToolTip( goPrevConflict->text() + omitsWhitespace );
-   goNextConflict = new KAction(i18n("Go to Next Conflict"), TQIconSet(TQPixmap(down2arrow)), CTRL+Key_PageDown, TQT_TQOBJECT(this), TQT_SLOT(slotGoNextConflict()), ac, "go_next_conflict");
+   goNextConflict = new TDEAction(i18n("Go to Next Conflict"), TQIconSet(TQPixmap(down2arrow)), CTRL+Key_PageDown, this, TQ_SLOT(slotGoNextConflict()), ac, "go_next_conflict");
    goNextConflict->setToolTip( goNextConflict->text() + omitsWhitespace );
-   goPrevUnsolvedConflict = new KAction(i18n("Go to Previous Unsolved Conflict"), TQIconSet(TQPixmap(prevunsolved)), 0, TQT_TQOBJECT(this), TQT_SLOT(slotGoPrevUnsolvedConflict()), ac, "go_prev_unsolved_conflict");
+   goPrevUnsolvedConflict = new TDEAction(i18n("Go to Previous Unsolved Conflict"), TQIconSet(TQPixmap(prevunsolved)), 0, this, TQ_SLOT(slotGoPrevUnsolvedConflict()), ac, "go_prev_unsolved_conflict");
    goPrevUnsolvedConflict->setToolTip( goPrevUnsolvedConflict->text() + includeWhitespace );
-   goNextUnsolvedConflict = new KAction(i18n("Go to Next Unsolved Conflict"), TQIconSet(TQPixmap(nextunsolved)), 0, TQT_TQOBJECT(this), TQT_SLOT(slotGoNextUnsolvedConflict()), ac, "go_next_unsolved_conflict");
+   goNextUnsolvedConflict = new TDEAction(i18n("Go to Next Unsolved Conflict"), TQIconSet(TQPixmap(nextunsolved)), 0, this, TQ_SLOT(slotGoNextUnsolvedConflict()), ac, "go_next_unsolved_conflict");
    goNextUnsolvedConflict->setToolTip( goNextUnsolvedConflict->text() + includeWhitespace );
-   chooseA = new KToggleAction(i18n("Select Line(s) From A"), TQIconSet(TQPixmap(iconA)), CTRL+Key_1, TQT_TQOBJECT(this), TQT_SLOT(slotChooseA()), ac, "merge_choose_a");
-   chooseB = new KToggleAction(i18n("Select Line(s) From B"), TQIconSet(TQPixmap(iconB)), CTRL+Key_2, TQT_TQOBJECT(this), TQT_SLOT(slotChooseB()), ac, "merge_choose_b");
-   chooseC = new KToggleAction(i18n("Select Line(s) From C"), TQIconSet(TQPixmap(iconC)), CTRL+Key_3, TQT_TQOBJECT(this), TQT_SLOT(slotChooseC()), ac, "merge_choose_c");
-   autoAdvance = new KToggleAction(i18n("Automatically Go to Next Unsolved Conflict After Source Selection"), TQIconSet(TQPixmap(autoadvance)), 0, TQT_TQOBJECT(this), TQT_SLOT(slotAutoAdvanceToggled()), ac, "merge_autoadvance");
+   chooseA = new TDEToggleAction(i18n("Select Line(s) From A"), TQIconSet(TQPixmap(iconA)), CTRL+Key_1, this, TQ_SLOT(slotChooseA()), ac, "merge_choose_a");
+   chooseB = new TDEToggleAction(i18n("Select Line(s) From B"), TQIconSet(TQPixmap(iconB)), CTRL+Key_2, this, TQ_SLOT(slotChooseB()), ac, "merge_choose_b");
+   chooseC = new TDEToggleAction(i18n("Select Line(s) From C"), TQIconSet(TQPixmap(iconC)), CTRL+Key_3, this, TQ_SLOT(slotChooseC()), ac, "merge_choose_c");
+   autoAdvance = new TDEToggleAction(i18n("Automatically Go to Next Unsolved Conflict After Source Selection"), TQIconSet(TQPixmap(autoadvance)), 0, this, TQ_SLOT(slotAutoAdvanceToggled()), ac, "merge_autoadvance");
 
-   showWhiteSpaceCharacters = new KToggleAction(i18n("Show Space && Tabulator Characters for Differences"), TQIconSet(TQPixmap(showwhitespacechars)), 0, TQT_TQOBJECT(this), TQT_SLOT(slotShowWhiteSpaceToggled()), ac, "diff_show_whitespace_characters");
-   showWhiteSpace = new KToggleAction(i18n("Show White Space"), TQIconSet(TQPixmap(showwhitespace)), 0, TQT_TQOBJECT(this), TQT_SLOT(slotShowWhiteSpaceToggled()), ac, "diff_show_whitespace");
+   showWhiteSpaceCharacters = new TDEToggleAction(i18n("Show Space && Tabulator Characters for Differences"), TQIconSet(TQPixmap(showwhitespacechars)), 0, this, TQ_SLOT(slotShowWhiteSpaceToggled()), ac, "diff_show_whitespace_characters");
+   showWhiteSpace = new TDEToggleAction(i18n("Show White Space"), TQIconSet(TQPixmap(showwhitespace)), 0, this, TQ_SLOT(slotShowWhiteSpaceToggled()), ac, "diff_show_whitespace");
 
-   showLineNumbers = new KToggleAction(i18n("Show Line Numbers"), TQIconSet(TQPixmap(showlinenumbers)), 0, TQT_TQOBJECT(this), TQT_SLOT(slotShowLineNumbersToggled()), ac, "diff_showlinenumbers");
-   chooseAEverywhere = new KAction(i18n("Choose A Everywhere"), CTRL+SHIFT+Key_1, TQT_TQOBJECT(this), TQT_SLOT(slotChooseAEverywhere()), ac, "merge_choose_a_everywhere");
-   chooseBEverywhere = new KAction(i18n("Choose B Everywhere"), CTRL+SHIFT+Key_2, TQT_TQOBJECT(this), TQT_SLOT(slotChooseBEverywhere()), ac, "merge_choose_b_everywhere");
-   chooseCEverywhere = new KAction(i18n("Choose C Everywhere"), CTRL+SHIFT+Key_3, TQT_TQOBJECT(this), TQT_SLOT(slotChooseCEverywhere()), ac, "merge_choose_c_everywhere");
-   chooseAForUnsolvedConflicts = new KAction(i18n("Choose A for All Unsolved Conflicts"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotChooseAForUnsolvedConflicts()), ac, "merge_choose_a_for_unsolved_conflicts");
-   chooseBForUnsolvedConflicts = new KAction(i18n("Choose B for All Unsolved Conflicts"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotChooseBForUnsolvedConflicts()), ac, "merge_choose_b_for_unsolved_conflicts");
-   chooseCForUnsolvedConflicts = new KAction(i18n("Choose C for All Unsolved Conflicts"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotChooseCForUnsolvedConflicts()), ac, "merge_choose_c_for_unsolved_conflicts");
-   chooseAForUnsolvedWhiteSpaceConflicts = new KAction(i18n("Choose A for All Unsolved Whitespace Conflicts"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotChooseAForUnsolvedWhiteSpaceConflicts()), ac, "merge_choose_a_for_unsolved_whitespace_conflicts");
-   chooseBForUnsolvedWhiteSpaceConflicts = new KAction(i18n("Choose B for All Unsolved Whitespace Conflicts"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotChooseBForUnsolvedWhiteSpaceConflicts()), ac, "merge_choose_b_for_unsolved_whitespace_conflicts");
-   chooseCForUnsolvedWhiteSpaceConflicts = new KAction(i18n("Choose C for All Unsolved Whitespace Conflicts"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotChooseCForUnsolvedWhiteSpaceConflicts()), ac, "merge_choose_c_for_unsolved_whitespace_conflicts");
-   autoSolve    = new KAction(i18n("Automatically Solve Simple Conflicts"),  0, TQT_TQOBJECT(this), TQT_SLOT(slotAutoSolve()),    ac, "merge_autosolve");
-   unsolve      = new KAction(i18n("Set Deltas to Conflicts"),               0, TQT_TQOBJECT(this), TQT_SLOT(slotUnsolve()),      ac, "merge_autounsolve");
-   mergeRegExp  = new KAction(i18n("Run Regular Expression Auto Merge"),     0, TQT_TQOBJECT(this), TQT_SLOT(slotRegExpAutoMerge()),ac, "merge_regexp_automerge" );
-   mergeHistory = new KAction(i18n("Automatically Solve History Conflicts"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotMergeHistory()), ac, "merge_versioncontrol_history" );
-   splitDiff    = new KAction(i18n("Split Diff At Selection"),               0, TQT_TQOBJECT(this), TQT_SLOT(slotSplitDiff()),    ac, "merge_splitdiff");
-   joinDiffs    = new KAction(i18n("Join Selected Diffs"),                   0, TQT_TQOBJECT(this), TQT_SLOT(slotJoinDiffs()),    ac, "merge_joindiffs");
+   showLineNumbers = new TDEToggleAction(i18n("Show Line Numbers"), TQIconSet(TQPixmap(showlinenumbers)), 0, this, TQ_SLOT(slotShowLineNumbersToggled()), ac, "diff_showlinenumbers");
+   chooseAEverywhere = new TDEAction(i18n("Choose A Everywhere"), CTRL+SHIFT+Key_1, this, TQ_SLOT(slotChooseAEverywhere()), ac, "merge_choose_a_everywhere");
+   chooseBEverywhere = new TDEAction(i18n("Choose B Everywhere"), CTRL+SHIFT+Key_2, this, TQ_SLOT(slotChooseBEverywhere()), ac, "merge_choose_b_everywhere");
+   chooseCEverywhere = new TDEAction(i18n("Choose C Everywhere"), CTRL+SHIFT+Key_3, this, TQ_SLOT(slotChooseCEverywhere()), ac, "merge_choose_c_everywhere");
+   chooseAForUnsolvedConflicts = new TDEAction(i18n("Choose A for All Unsolved Conflicts"), 0, this, TQ_SLOT(slotChooseAForUnsolvedConflicts()), ac, "merge_choose_a_for_unsolved_conflicts");
+   chooseBForUnsolvedConflicts = new TDEAction(i18n("Choose B for All Unsolved Conflicts"), 0, this, TQ_SLOT(slotChooseBForUnsolvedConflicts()), ac, "merge_choose_b_for_unsolved_conflicts");
+   chooseCForUnsolvedConflicts = new TDEAction(i18n("Choose C for All Unsolved Conflicts"), 0, this, TQ_SLOT(slotChooseCForUnsolvedConflicts()), ac, "merge_choose_c_for_unsolved_conflicts");
+   chooseAForUnsolvedWhiteSpaceConflicts = new TDEAction(i18n("Choose A for All Unsolved Whitespace Conflicts"), 0, this, TQ_SLOT(slotChooseAForUnsolvedWhiteSpaceConflicts()), ac, "merge_choose_a_for_unsolved_whitespace_conflicts");
+   chooseBForUnsolvedWhiteSpaceConflicts = new TDEAction(i18n("Choose B for All Unsolved Whitespace Conflicts"), 0, this, TQ_SLOT(slotChooseBForUnsolvedWhiteSpaceConflicts()), ac, "merge_choose_b_for_unsolved_whitespace_conflicts");
+   chooseCForUnsolvedWhiteSpaceConflicts = new TDEAction(i18n("Choose C for All Unsolved Whitespace Conflicts"), 0, this, TQ_SLOT(slotChooseCForUnsolvedWhiteSpaceConflicts()), ac, "merge_choose_c_for_unsolved_whitespace_conflicts");
+   autoSolve    = new TDEAction(i18n("Automatically Solve Simple Conflicts"),  0, this, TQ_SLOT(slotAutoSolve()),    ac, "merge_autosolve");
+   unsolve      = new TDEAction(i18n("Set Deltas to Conflicts"),               0, this, TQ_SLOT(slotUnsolve()),      ac, "merge_autounsolve");
+   mergeRegExp  = new TDEAction(i18n("Run Regular Expression Auto Merge"),     0, this, TQ_SLOT(slotRegExpAutoMerge()),ac, "merge_regexp_automerge" );
+   mergeHistory = new TDEAction(i18n("Automatically Solve History Conflicts"), 0, this, TQ_SLOT(slotMergeHistory()), ac, "merge_versioncontrol_history" );
+   splitDiff    = new TDEAction(i18n("Split Diff At Selection"),               0, this, TQ_SLOT(slotSplitDiff()),    ac, "merge_splitdiff");
+   joinDiffs    = new TDEAction(i18n("Join Selected Diffs"),                   0, this, TQ_SLOT(slotJoinDiffs()),    ac, "merge_joindiffs");
 
-   showWindowA = new KToggleAction(i18n("Show Window A"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotShowWindowAToggled()), ac, "win_show_a");
-   showWindowB = new KToggleAction(i18n("Show Window B"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotShowWindowBToggled()), ac, "win_show_b");
-   showWindowC = new KToggleAction(i18n("Show Window C"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotShowWindowCToggled()), ac, "win_show_c");
-   winFocusNext = new KAction(i18n("Focus Next Window"), ALT+Key_Right, TQT_TQOBJECT(this), TQT_SLOT(slotWinFocusNext()), ac, "win_focus_next");
+   showWindowA = new TDEToggleAction(i18n("Show Window A"), 0, this, TQ_SLOT(slotShowWindowAToggled()), ac, "win_show_a");
+   showWindowB = new TDEToggleAction(i18n("Show Window B"), 0, this, TQ_SLOT(slotShowWindowBToggled()), ac, "win_show_b");
+   showWindowC = new TDEToggleAction(i18n("Show Window C"), 0, this, TQ_SLOT(slotShowWindowCToggled()), ac, "win_show_c");
+   winFocusNext = new TDEAction(i18n("Focus Next Window"), ALT+Key_Right, this, TQ_SLOT(slotWinFocusNext()), ac, "win_focus_next");
 
-   overviewModeNormal = new KToggleAction(i18n("Normal Overview"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotOverviewNormal()), ac, "diff_overview_normal");
-   overviewModeAB     = new KToggleAction(i18n("A vs. B Overview"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotOverviewAB()), ac, "diff_overview_ab");
-   overviewModeAC     = new KToggleAction(i18n("A vs. C Overview"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotOverviewAC()), ac, "diff_overview_ac");
-   overviewModeBC     = new KToggleAction(i18n("B vs. C Overview"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotOverviewBC()), ac, "diff_overview_bc");
-   wordWrap     = new KToggleAction(i18n("Word Wrap Diff Windows"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotWordWrapToggled()), ac, "diff_wordwrap");
-   addManualDiffHelp  = new KAction(i18n("Add Manual Diff Alignment"), TQt::CTRL+TQt::Key_Y, TQT_TQOBJECT(this), TQT_SLOT(slotAddManualDiffHelp()), ac, "diff_add_manual_diff_help");
-   clearManualDiffHelpList  = new KAction(i18n("Clear All Manual Diff Alignments"), TQt::CTRL+TQt::SHIFT+TQt::Key_Y, TQT_TQOBJECT(this), TQT_SLOT(slotClearManualDiffHelpList()), ac, "diff_clear_manual_diff_help_list");
+   overviewModeNormal = new TDEToggleAction(i18n("Normal Overview"), 0, this, TQ_SLOT(slotOverviewNormal()), ac, "diff_overview_normal");
+   overviewModeAB     = new TDEToggleAction(i18n("A vs. B Overview"), 0, this, TQ_SLOT(slotOverviewAB()), ac, "diff_overview_ab");
+   overviewModeAC     = new TDEToggleAction(i18n("A vs. C Overview"), 0, this, TQ_SLOT(slotOverviewAC()), ac, "diff_overview_ac");
+   overviewModeBC     = new TDEToggleAction(i18n("B vs. C Overview"), 0, this, TQ_SLOT(slotOverviewBC()), ac, "diff_overview_bc");
+   wordWrap     = new TDEToggleAction(i18n("Word Wrap Diff Windows"), 0, this, TQ_SLOT(slotWordWrapToggled()), ac, "diff_wordwrap");
+   addManualDiffHelp  = new TDEAction(i18n("Add Manual Diff Alignment"), TQt::CTRL+TQt::Key_Y, this, TQ_SLOT(slotAddManualDiffHelp()), ac, "diff_add_manual_diff_help");
+   clearManualDiffHelpList  = new TDEAction(i18n("Clear All Manual Diff Alignments"), TQt::CTRL+TQt::SHIFT+TQt::Key_Y, this, TQ_SLOT(slotClearManualDiffHelpList()), ac, "diff_clear_manual_diff_help_list");
 
 #ifdef _WIN32
-   new KAction(i18n("Focus Next Window"), TQt::CTRL+TQt::Key_Tab, TQT_TQOBJECT(this), TQT_SLOT(slotWinFocusNext()), ac, "win_focus_next", false, false);
+   new TDEAction(i18n("Focus Next Window"), TQt::CTRL+TQt::Key_Tab, this, TQ_SLOT(slotWinFocusNext()), ac, "win_focus_next", false, false);
 #endif
-   winFocusPrev = new KAction(i18n("Focus Prev Window"), TQt::ALT+TQt::Key_Left, TQT_TQOBJECT(this), TQT_SLOT(slotWinFocusPrev()), ac, "win_focus_prev");
-   winToggleSplitOrientation = new KAction(i18n("Toggle Split Orientation"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotWinToggleSplitterOrientation()), ac, "win_toggle_split_orientation");
+   winFocusPrev = new TDEAction(i18n("Focus Prev Window"), TQt::ALT+TQt::Key_Left, this, TQ_SLOT(slotWinFocusPrev()), ac, "win_focus_prev");
+   winToggleSplitOrientation = new TDEAction(i18n("Toggle Split Orientation"), 0, this, TQ_SLOT(slotWinToggleSplitterOrientation()), ac, "win_toggle_split_orientation");
 
-   dirShowBoth = new KToggleAction(i18n("Dir && Text Split Screen View"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotDirShowBoth()), ac, "win_dir_show_both");
+   dirShowBoth = new TDEToggleAction(i18n("Dir && Text Split Screen View"), 0, this, TQ_SLOT(slotDirShowBoth()), ac, "win_dir_show_both");
    dirShowBoth->setChecked( true );
-   dirViewToggle = new KAction(i18n("Toggle Between Dir && Text View"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotDirViewToggle()), actionCollection(), "win_dir_view_toggle");
+   dirViewToggle = new TDEAction(i18n("Toggle Between Dir && Text View"), 0, this, TQ_SLOT(slotDirViewToggle()), actionCollection(), "win_dir_view_toggle");
 
    m_pMergeEditorPopupMenu = new TQPopupMenu( this );
    chooseA->plug( m_pMergeEditorPopupMenu );
@@ -568,7 +568,7 @@ void KDiff3App::initStatusBar()
      statusBar()->message( i18n("Ready.") );
 }
 
-void KDiff3App::saveOptions( KConfig* config )
+void KDiff3App::saveOptions( TDEConfig* config )
 {
    if ( !m_bAutoMode )
    {
@@ -629,7 +629,7 @@ bool KDiff3App::queryClose()
 
 
 /////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATION
+// TQ_SLOT IMPLEMENTATION
 /////////////////////////////////////////////////////////////////////
 
 
@@ -927,7 +927,7 @@ void KDiff3App::slotFileQuit()
    if( !queryClose() )
        return;      // Don't quit
 
-   KApplication::exit( isFileSaved() ? 0 : 1 );
+   TDEApplication::exit( isFileSaved() ? 0 : 1 );
 }
 
 
