@@ -263,7 +263,7 @@ public:
    {
       m_pVar = pVar;
       m_defaultVal = defaultVal;
-      TQIntValidator* v = new TQIntValidator(TQT_TQOBJECT(this));
+      TQIntValidator* v = new TQIntValidator(this);
       v->setRange( rangeMin, rangeMax );
       setValidator( v );
    }
@@ -847,7 +847,7 @@ void OptionDialog::setupMergePage( void )
       );
    ++line;
 
-   TQGroupBox* pGroupBox = new TQGroupBox( 2, Qt::Horizontal, i18n("Automatic Merge Regular Expression"), page);
+   TQGroupBox* pGroupBox = new TQGroupBox( 2, TQt::Horizontal, i18n("Automatic Merge Regular Expression"), page);
    gbox->addMultiCellWidget( pGroupBox, line,line,0,1);
    ++line;
    {
@@ -873,7 +873,7 @@ void OptionDialog::setupMergePage( void )
       ++line;
    }
 
-   pGroupBox = new TQGroupBox( 2, Qt::Horizontal, i18n("Version Control History Merging"), page);
+   pGroupBox = new TQGroupBox( 2, TQt::Horizontal, i18n("Version Control History Merging"), page);
    gbox->addMultiCellWidget( pGroupBox, line,line,0,1);
    ++line;
    {
@@ -922,7 +922,7 @@ void OptionDialog::setupMergePage( void )
             //int year   = newHistoryEntry.cap(4).toInt();
             //TQString time = newHistoryEntry.cap(5);
             //TQString name = newHistoryEntry.cap(6);
-      TQString defaultSortKeyOrder = "4,3,2,5,1,6"; //TQDate(year,month,day).toString(Qt::ISODate) +" "+ time + " " + branch + " " + name;
+      TQString defaultSortKeyOrder = "4,3,2,5,1,6"; //TQDate(year,month,day).toString(TQt::ISODate) +" "+ time + " " + branch + " " + name;
 
       label = new TQLabel( i18n("History entry start sort key order:"), page );
       gbox->addWidget( label, line, 0 );
@@ -936,7 +936,7 @@ void OptionDialog::setupMergePage( void )
                                  "See the documentation for details.");
       TQToolTip::add( label, s_historyEntryStartSortKeyOrderToolTip );
       m_pHistorySortKeyOrderLineEdit->setEnabled(false);
-      connect( m_pHistoryMergeSorting, TQT_SIGNAL(toggled(bool)), m_pHistorySortKeyOrderLineEdit, TQT_SLOT(setEnabled(bool)));
+      connect( m_pHistoryMergeSorting, TQ_SIGNAL(toggled(bool)), m_pHistorySortKeyOrderLineEdit, TQ_SLOT(setEnabled(bool)));
       ++line;
 
       m_pHistoryAutoMerge = new OptionCheckBox( i18n("Merge version control history on merge start"), false, "RunHistoryAutoMergeOnMergeStart", &m_bRunHistoryAutoMergeOnMergeStart, page, this );
@@ -954,7 +954,7 @@ void OptionDialog::setupMergePage( void )
 
    TQPushButton* pButton = new TQPushButton( i18n("Test your regular expressions"), page );
    gbox->addWidget( pButton, line, 0 );
-   connect( pButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotHistoryMergeRegExpTester()));
+   connect( pButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotHistoryMergeRegExpTester()));
    ++line;
 
    label = new TQLabel( i18n("Irrelevant merge command:"), page );
@@ -1117,7 +1117,7 @@ void OptionDialog::setupDirectoryMergePage( void )
    TQToolTip::add( pWhiteSpaceDiffsEqual, i18n(
                   "If files differ only by white space consider them equal.\n"
                   "This is only active when full analysis is chosen."  ) );
-   connect(pFullAnalysis, TQT_SIGNAL(toggled(bool)), pWhiteSpaceDiffsEqual, TQT_SLOT(setEnabled(bool)));
+   connect(pFullAnalysis, TQ_SIGNAL(toggled(bool)), pWhiteSpaceDiffsEqual, TQ_SLOT(setEnabled(bool)));
    pWhiteSpaceDiffsEqual->setEnabled(false);
    ++line;
 
@@ -1418,10 +1418,10 @@ static char* countryMap[]={
    gbox->addWidget( m_pEncodingPPComboBox, line, 1 );   
    ++line;
 
-   connect(m_pSameEncoding, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotEncodingChanged()));
-   connect(m_pEncodingAComboBox, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotEncodingChanged()));
-   connect(m_pAutoDetectUnicodeA, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotEncodingChanged()));
-   connect(m_pAutoSelectOutEncoding, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotEncodingChanged()));
+   connect(m_pSameEncoding, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotEncodingChanged()));
+   connect(m_pEncodingAComboBox, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotEncodingChanged()));
+   connect(m_pAutoDetectUnicodeA, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotEncodingChanged()));
+   connect(m_pAutoSelectOutEncoding, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotEncodingChanged()));
 
    OptionCheckBox* pRightToLeftLanguage = new OptionCheckBox( i18n("Right To Left Language"), false, "RightToLeftLanguage", &m_bRightToLeftLanguage, page, this );
    gbox->addMultiCellWidget( pRightToLeftLanguage, line, line, 0, 1 );
@@ -1468,14 +1468,14 @@ void OptionDialog::setupIntegrationPage( void )
                  "Integrate with Rational ClearCase from IBM.\n"
                  "Modifies the \"map\" file in ClearCase-subdir \"lib/mgrs\"\n"
                  "(Only enabled when ClearCase \"bin\" directory is in the path.)"));
-   connect(pIntegrateWithClearCase, TQT_SIGNAL(clicked()),this, TQT_SLOT(slotIntegrateWithClearCase()) );
+   connect(pIntegrateWithClearCase, TQ_SIGNAL(clicked()),this, TQ_SLOT(slotIntegrateWithClearCase()) );
    pIntegrateWithClearCase->setEnabled( integrateWithClearCase( "existsClearCase", "" )!=0 );
 
    TQPushButton* pRemoveClearCaseIntegration = new TQPushButton( i18n("Remove ClearCase Integration"), page);
    gbox->addWidget( pRemoveClearCaseIntegration, line, 1 );
    TQToolTip::add( pRemoveClearCaseIntegration, i18n(
                  "Restore the old \"map\" file from before doing the Clearcase integration."));
-   connect(pRemoveClearCaseIntegration, TQT_SIGNAL(clicked()),this, TQT_SLOT(slotRemoveClearCaseIntegration()) );
+   connect(pRemoveClearCaseIntegration, TQ_SIGNAL(clicked()),this, TQ_SLOT(slotRemoveClearCaseIntegration()) );
    pRemoveClearCaseIntegration->setEnabled( integrateWithClearCase( "existsClearCase", "" )!=0 );
 
    ++line;
